ClerkHttpClient

Struct ClerkHttpClient 

pub struct ClerkHttpClient { /* private fields */ }
Custom client wrapper that behaves like reqwest::Client but adds Clerk-specific functionality

Implementations

Source

impl ClerkHttpClient

ClerkHttpClient that mimics ReqwestClient with pre and post hooks To be able to run Clerk in non browser environment we need to identify our selves to Clerk with Client Authorization header We inject the header to the request and parse returned header and keep the ClerkState updated with most current value

pub fn new( client: ReqwestClient, state: Arc<RwLock<ClerkState>>, client_kind: ClientKind, ) -> Self

Creates a new ClerkHttpClient

pub fn set_dev_browser_token_id(&self, token_id: String)

When running in browser one needs “DevBrowser auth” when running against Clerk development environment

pub async fn execute(&self, request: Request) -> Result<Response, Error>

pub fn request<U: IntoUrl>(&self, method: Method, url: U) -> RequestBuilder

pub fn get<U: IntoUrl>(&self, url: U) -> RequestBuilder

pub fn post<U: IntoUrl>(&self, url: U) -> RequestBuilder

pub fn put<U: IntoUrl>(&self, url: U) -> RequestBuilder

pub fn patch<U: IntoUrl>(&self, url: U) -> RequestBuilder

pub fn delete<U: IntoUrl>(&self, url: U) -> RequestBuilder

pub fn head<U: IntoUrl>(&self, url: U) -> RequestBuilder