pub struct ClientSession {Show 15 fields
pub id: String,
pub object: Object,
pub status: Status,
pub expire_at: i64,
pub abandon_at: i64,
pub last_active_at: i64,
pub last_active_token: Option<Option<Box<Token>>>,
pub actor: Option<Option<HashMap<String, Value>>>,
pub tasks: Option<Option<Vec<ClientSessionTask>>>,
pub last_active_organization_id: Option<String>,
pub user: Option<Box<ClientUser>>,
pub public_user_data: Option<Value>,
pub factor_verification_age: Vec<i64>,
pub created_at: i64,
pub updated_at: i64,
}Fields
id: Stringobject: ObjectString representing the object’s type. Objects of the same type share the same value.
status: Statusexpire_at: i64abandon_at: i64last_active_at: i64last_active_token: Option<Option<Box<Token>>>actor: Option<Option<HashMap<String, Value>>>tasks: Option<Option<Vec<ClientSessionTask>>>last_active_organization_id: Option<String>user: Option<Box<ClientUser>>public_user_data: Option<Value>factor_verification_age: Vec<i64>Each item represents the minutes that have passed since the last time a first or second factor were verified.
created_at: i64Unix timestamp of creation.
updated_at: i64Unix timestamp of last update.
Implementations
Sourceimpl ClientSession
impl ClientSession