ClientSignUp

Struct ClientSignUp 

pub struct ClientSignUp {
Show 23 fields pub object: Object, pub id: String, pub status: Status, pub required_fields: Vec<String>, pub optional_fields: Vec<String>, pub missing_fields: Vec<String>, pub unverified_fields: Vec<String>, pub verifications: Box<ClientSignUpVerifications>, pub username: Option<String>, pub email_address: Option<String>, pub phone_number: Option<String>, pub web3_wallet: Option<String>, pub password_enabled: bool, pub first_name: Option<String>, pub last_name: Option<String>, pub unsafe_metadata: Option<HashMap<String, Value>>, pub public_metadata: Option<HashMap<String, Value>>, pub custom_action: bool, pub external_id: Option<String>, pub created_session_id: Option<String>, pub created_user_id: Option<String>, pub abandon_at: i64, pub legal_accepted_at: Option<i64>,
}

Fields

object: Object

String representing the object’s type. Objects of the same type share the same value.

id: String

Unique identifier for this sign up.

status: Statusrequired_fields: Vec<String>

List of required fields which need to be supplied to the current sign-up. These fields are mandatory in order for the sign-up to satisfy the attached registration policy and be marked as complete.

optional_fields: Vec<String>

List of optional fields which can be supplied to the current sign-up. These fields are not required and their absence does not prevent the sign-up to be marked as complete.

missing_fields: Vec<String>

List of the missing fields which still need to be supplied to the current sign-up. These fields are mandatory in order for the sign-up to satisfy the attached registration policy and be marked as complete.

unverified_fields: Vec<String>

List of fields which are already supplied to the current sign-up but they need to be verified. Example of such fields are email addresses and phone numbers.

verifications: Box<ClientSignUpVerifications>

Group for all available verifications.

username: Option<String>email_address: Option<String>phone_number: Option<String>web3_wallet: Option<String>password_enabled: boolfirst_name: Option<String>last_name: Option<String>unsafe_metadata: Option<HashMap<String, Value>>

Custom JSON that callers can use to store arbitrary values that make sense in the context of the current sign up.

public_metadata: Option<HashMap<String, Value>>

Custom JSON that can be used to store arbitrary values which will end up in the user’s public metadata. This field can only be populated from the application’s BE. At this point, this can be done via invitations.

custom_action: boolexternal_id: Option<String>created_session_id: Option<String>created_user_id: Option<String>abandon_at: i64

Unix timestamp at which the sign up will be abandoned.

legal_accepted_at: Option<i64>

Unix timestamp at which the user accepted the legal requirements.

Implementations

Source

impl ClientSignUp

pub fn new( object: Object, id: String, status: Status, required_fields: Vec<String>, optional_fields: Vec<String>, missing_fields: Vec<String>, unverified_fields: Vec<String>, verifications: ClientSignUpVerifications, username: Option<String>, email_address: Option<String>, phone_number: Option<String>, web3_wallet: Option<String>, password_enabled: bool, first_name: Option<String>, last_name: Option<String>, custom_action: bool, external_id: Option<String>, created_session_id: Option<String>, created_user_id: Option<String>, abandon_at: i64, legal_accepted_at: Option<i64>, ) -> ClientSignUp