pub struct ClientUser {Show 41 fields
pub id: String,
pub object: Object,
pub username: Option<String>,
pub first_name: Option<String>,
pub last_name: Option<String>,
pub image_url: Option<String>,
pub has_image: bool,
pub primary_email_address_id: Option<String>,
pub primary_phone_number_id: Option<String>,
pub primary_web3_wallet_id: Option<String>,
pub password_enabled: bool,
pub two_factor_enabled: bool,
pub totp_enabled: bool,
pub backup_code_enabled: bool,
pub email_addresses: Vec<ClientEmailAddress>,
pub phone_numbers: Vec<ClientPhoneNumber>,
pub web3_wallets: Vec<ClientWeb3Wallet>,
pub passkeys: Vec<ClientPasskey>,
pub organization_memberships: Option<Vec<ClientOrganizationMembership>>,
pub external_accounts: Vec<ExternalAccountWithVerification>,
pub saml_accounts: Vec<ClientSamlAccount>,
pub password_last_updated_at: Option<Option<i64>>,
pub public_metadata: HashMap<String, Value>,
pub private_metadata: Option<HashMap<String, Value>>,
pub unsafe_metadata: Option<HashMap<String, Value>>,
pub external_id: Option<String>,
pub last_sign_in_at: Option<i64>,
pub banned: bool,
pub locked: bool,
pub lockout_expires_in_seconds: Option<i64>,
pub verification_attempts_remaining: Option<i64>,
pub created_at: i64,
pub updated_at: i64,
pub delete_self_enabled: bool,
pub create_organization_enabled: bool,
pub create_organizations_limit: Option<i64>,
pub last_active_at: Option<i64>,
pub mfa_enabled_at: Option<i64>,
pub mfa_disabled_at: Option<i64>,
pub legal_accepted_at: Option<i64>,
pub profile_image_url: Option<String>,
}Fields
id: Stringobject: ObjectString representing the object’s type. Objects of the same type share the same value.
username: Option<String>first_name: Option<String>last_name: Option<String>image_url: Option<String>has_image: boolprimary_email_address_id: Option<String>primary_phone_number_id: Option<String>primary_web3_wallet_id: Option<String>password_enabled: booltwo_factor_enabled: booltotp_enabled: boolbackup_code_enabled: boolemail_addresses: Vec<ClientEmailAddress>phone_numbers: Vec<ClientPhoneNumber>web3_wallets: Vec<ClientWeb3Wallet>passkeys: Vec<ClientPasskey>organization_memberships: Option<Vec<ClientOrganizationMembership>>external_accounts: Vec<ExternalAccountWithVerification>saml_accounts: Vec<ClientSamlAccount>password_last_updated_at: Option<Option<i64>>Unix timestamp of last update.
public_metadata: HashMap<String, Value>private_metadata: Option<HashMap<String, Value>>unsafe_metadata: Option<HashMap<String, Value>>external_id: Option<String>last_sign_in_at: Option<i64>Unix timestamp of last sign-in.
banned: boolFlag to denote whether user is banned or not.
locked: boolFlag to denote whether user is currently locked, i.e. restricted from signing in or not.
lockout_expires_in_seconds: Option<i64>The number of seconds remaining until the lockout period expires for a locked user. A null value for a locked user indicates that lockout never expires.
verification_attempts_remaining: Option<i64>The number of verification attempts remaining until the user is locked. Null if account lockout is not enabled. Note: if a user is locked explicitly via the Backend API, they may still have verification attempts remaining.
created_at: i64Unix timestamp of creation.
updated_at: i64Unix timestamp of last update.
delete_self_enabled: boolIf enabled, user can delete themselves via FAPI.
create_organization_enabled: boolIf enabled, user can create organizations via FAPI.
create_organizations_limit: Option<i64>The maximum number of organizations the user can create. 0 means unlimited.
last_active_at: Option<i64>Unix timestamp of the latest session activity, with day precision.
mfa_enabled_at: Option<i64>Unix timestamp at which the user enabled MFA.
mfa_disabled_at: Option<i64>Unix timestamp at which the user disabled MFA.
legal_accepted_at: Option<i64>Unix timestamp at which the user accepted the legal requirements.
profile_image_url: Option<String>Deprecated. Use image_url instead.
Implementations
Sourceimpl ClientUser
impl ClientUser
pub fn new( id: String, object: Object, username: Option<String>, first_name: Option<String>, last_name: Option<String>, has_image: bool, primary_email_address_id: Option<String>, primary_phone_number_id: Option<String>, primary_web3_wallet_id: Option<String>, password_enabled: bool, two_factor_enabled: bool, totp_enabled: bool, backup_code_enabled: bool, email_addresses: Vec<ClientEmailAddress>, phone_numbers: Vec<ClientPhoneNumber>, web3_wallets: Vec<ClientWeb3Wallet>, passkeys: Vec<ClientPasskey>, external_accounts: Vec<ExternalAccountWithVerification>, saml_accounts: Vec<ClientSamlAccount>, public_metadata: HashMap<String, Value>, external_id: Option<String>, last_sign_in_at: Option<i64>, banned: bool, locked: bool, lockout_expires_in_seconds: Option<i64>, verification_attempts_remaining: Option<i64>, created_at: i64, updated_at: i64, delete_self_enabled: bool, create_organization_enabled: bool, last_active_at: Option<i64>, mfa_enabled_at: Option<i64>, mfa_disabled_at: Option<i64>, legal_accepted_at: Option<i64>, ) -> ClientUser