pub async fn create_dev_browser(
configuration: &Configuration,
) -> Result<DevBrowser, Error<CreateDevBrowserError>>Expand description
Generate an Dev Browser API token. This is used to authenticate Development Instances with the DevBrowser scheme. It must be set before making any request to a dev instance, even for endpoints that are public.